### calculate_geodetic_distance

Compute geodesic distance and azimuths between two lon/lat points.

- Tool: `calculate_geodetic_distance`

Parameters

- point1 (array [lon, lat])
- point2 (array [lon, lat])
- ellps (string, default "WGS84")

Returns

- distance (number, meters), forward_azimuth, back_azimuth; status, message
